.. _gedidb_docs_mainpage:

########################
gediDB Documentation
########################

.. toctree::
   :maxdepth: 1
   :hidden:

   Installation <user/installing>
   User Guide <user/index>
   GEDI Global Database <user/tiledb_database>
   API Reference <user/api>
   Examples <auto_examples/index>
   Development <user/contributing>

**Version**: |version|

**gediDB** is an open-source Python package designed to simplify working with GEDI L2A-B and L4A-C datasets, streamlining data analysis for efficient data exploration. It offers intuitive modules for processing, querying, and analyzing GEDI data stored in **tileDB databases**.

.. grid:: 1 1 2 2
    :gutter: 2 3 4 4

    .. grid-item-card::
        :img-top: /_static/index-images/getting_started.svg
        :text-align: center

        **Getting Started**
        ^^^

        New to gediDB? Start here for a quick introduction to gediDB’s core features, with examples to help you jump right in.

        +++

        .. button-ref:: user/quick-overview
            :expand:
            :color: primary
            :click-parent:

            Explore Quick Overview

    .. grid-item-card::
        :img-top: /_static/index-images/user_guide.svg
        :text-align: center

        **User Guide**
        ^^^

        Dive into the User Guide for detailed explanations of key concepts, workflows, and practical applications within gediDB.

        +++

        .. button-ref:: user
            :expand:
            :color: primary
            :click-parent:

            Access User Guide

    .. grid-item-card::
        :img-top: /_static/index-images/api_reference.svg
        :text-align: center

        **API Reference**
        ^^^

        The reference guide contains a detailed description of the gediDB API.
        The reference describes how the methods work and which parameters can
        be used.

        +++

        .. button-ref:: user/api
            :expand:
            :color: primary
            :click-parent:

            Explore API Reference

    .. grid-item-card::
        :img-top: /_static/index-images/contributor.svg
        :text-align: center

        **Contributor’s Guide**
        ^^^

        Want to contribute to gediDB? From code to documentation improvements, this guide shows you how to get involved.

        +++

        .. button-ref:: user/contributing
            :expand:
            :color: primary
            :click-parent:

            View Contributor's Guide
